Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(88)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutBlockFlow.cpp

Issue 2758683002: Replace ASSERT_NOT_REACHED with NOTREACHED in core/layout/ (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutBlockFlow.cpp
diff --git a/third_party/WebKit/Source/core/layout/LayoutBlockFlow.cpp b/third_party/WebKit/Source/core/layout/LayoutBlockFlow.cpp
index f5db6a13bbda74650bdb0f39a0f1fe37015c4a57..fe358044fd89652c9229c7d5e2e8a23c421ade1d 100644
--- a/third_party/WebKit/Source/core/layout/LayoutBlockFlow.cpp
+++ b/third_party/WebKit/Source/core/layout/LayoutBlockFlow.cpp
@@ -2747,7 +2747,7 @@ LayoutUnit LayoutBlockFlow::getClearDelta(LayoutBox* child,
if (newLogicalTop < logicalTop)
break;
}
- ASSERT_NOT_REACHED();
+ NOTREACHED();
}
return result;
}
@@ -3069,7 +3069,7 @@ void LayoutBlockFlow::removeChild(LayoutObject* oldChild) {
else if (curr->isLayoutBlockFlow())
toLayoutBlockFlow(curr)->setContinuation(nextContinuation);
else
- ASSERT_NOT_REACHED();
+ NOTREACHED();
break;
}
@@ -4222,7 +4222,7 @@ LayoutMultiColumnFlowThread* LayoutBlockFlow::createMultiColumnFlowThread(
UseCounter::count(document(), UseCounter::CSSOverflowPaged);
return LayoutPagedFlowThread::createAnonymous(document(), styleRef());
default:
- ASSERT_NOT_REACHED();
+ NOTREACHED();
return nullptr;
}
}
@@ -4504,7 +4504,7 @@ PositionWithAffinity LayoutBlockFlow::positionForPoint(
}
// Can't reach this. We have a root line box, but it has no kids.
// FIXME: This should ASSERT_NOT_REACHED(), but clicking on placeholder text
// seems to hit this code path.
return createPositionWithAffinity(0);
}
@@ -4504,7 +4504,7 @@ PositionWithAffinity LayoutBlockFlow::positionForPoint(
}
// Can't reach this. We have a root line box, but it has no kids.
- // FIXME: This should ASSERT_NOT_REACHED(), but clicking on placeholder text
+ // FIXME: This should NOTREACHED(), but clicking on placeholder text
// seems to hit this code path.
return createPositionWithAffinity(0);

Powered by Google App Engine
This is Rietveld 408576698